Coverage report

File | function | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/retemplar/core.py | RetemplarCore.__init__ | 1 | 0 | 0 | 100%
src/retemplar/core.py | RetemplarCore.adopt_template | 11 | 0 | 0 | 100%
src/retemplar/core.py | RetemplarCore.plan_upgrade | 13 | 0 | 0 | 100%
src/retemplar/core.py | RetemplarCore.apply_changes | 20 | 0 | 0 | 100%
src/retemplar/core.py | RetemplarCore.detect_drift | 7 | 0 | 0 | 100%
src/retemplar/core.py | (no function) | 15 | 0 | 0 | 100%
Total |  | 67 | 0 | 0 | 100%

No items found using the specified filter.